from setuptools import setup

setup(name='bg11_distributions',
      version='0.2',
      description='Gaussian & Binomial distributions',
      packages=['bg11_distributions'],
      zip_safe=False)
